/**
 * Converts element hits to footprints (uniqueIds)
 */
import { IBranchHit, IConvertedFootprints, IHitFileData, IMethodData, IPosition } from "./contracts";
import { RelativePathResolver } from "./relative-path-resolver";
import { SourceMapData } from "./source-map-data";
import bunyan = require('bunyan');
export declare class HitsConverter {
    static readonly METHOD_ID_DEL = "@";
    static readonly BRANCH_ID_DEL = "|";
    private relativePathResolver;
    private projectRoot;
    private sourceMapData;
    protected logger: bunyan;
    constructor(relativePathResolver: RelativePathResolver, sourceMapData: SourceMapData, projectRoot: string, logger: bunyan);
    convertHits(hitFilesData: IHitFileData[]): IConvertedFootprints;
    private createMethodIds;
    protected getDeclStart(hit: IMethodData): {
        line: number;
        column: number;
    };
    protected getDecl(hit: IMethodData): import("./contracts").IIstanbulLocation;
    protected getStartLoc(hit: IMethodData): {
        line: number;
        column: number;
    };
    protected getLeaveStartLoc(hit: IBranchHit, leaveIdx: number): {
        line: number;
        column: number;
    };
    private createBranchIds;
    protected getMethodUniqueId(startLoc: IPosition, relativePath: string, absolutePath: string): string;
    protected getBranchUniqueId(startLoc: IPosition, relativePath: string, absolutePath: string, leaveIndex: number): string;
    private resolveIdParts;
    private buildMethodUniqueId;
    protected formatLoc(loc: IPosition): string;
}
